SET NUMERIC_ROUNDABORT OFF
GO
SET ANSI_PADDING, ANSI_WARNINGS, CONCAT_NULL_YIELDS_NULL, ARITHABORT, QUOTED_IDENTIFIER, ANSI_NULLS ON
GO
IF EXISTS (SELECT * FROM tempdb..sysobjects WHERE id=OBJECT_ID('tempdb..#tmpErrors')) DROP TABLE #tmpErrors
GO
CREATE TABLE #tmpErrors (Error int)
GO
SET XACT_ABORT ON
GO
SET TRANSACTION ISOLATION LEVEL SERIALIZABLE
GO
BEGIN TRANSACTION
GO
PRINT N'Altering [dbo].[GetFTESLA]'
GO

ALTER PROCEDURE [dbo].[GetFTESLA]
--- Stored procedure to return FTE Transactions that are required to be checked for SLA
AS
SET NOCOUNT ON
SELECT * FROM dbo.TrnFTETransaction T WHERE (T.[Status] IS NOT NULL) AND (T.[SLAClass] IS NOT NULL) AND (T.Status < 3)

GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Altering [dbo].[InsertFTETransaction]'
GO
ALTER PROCEDURE [dbo].[InsertFTETransaction] 
--- Routine to add FTE Header Records
	@TransactionId NVARCHAR(50),
	@TransDate DATETIME,
	@SourceAgent NVARCHAR(50),
	@SourceQM NVARCHAR(50),
	@SourceAgentInfo NVARCHAR(512),
	@DestAgent NVARCHAR(50),
	@DestQM NVARCHAR(50),
	@DestAgentInfo NVARCHAR(512),
	@JobId NVARCHAR(50),
	@JobName NVARCHAR(200),
	@OrigHost NVARCHAR(150),
	@OrigUser NVARCHAR(50),
	@OrigMQMUser NVARCHAR(50),
	@MQACompId INT,
	@SLAClass NVARCHAR(50),
	@MQAInfo NTEXT,
	@Supplemental NTEXT
AS
BEGIN
	SET NOCOUNT ON;
	BEGIN TRANSACTION	
--- Update the Job File
    SELECT * FROM TrnFTEJob WHERE [JobId] = @JobId
    IF (@@ROWCOUNT <= 0)
    BEGIN
		INSERT INTO TrnFTEJob ([JobId], [JobDate], [Name], [OrigHost], [OrigUser], [OrigMQMUser],[Status], [LastUpdate]) VALUES (@JobId, @TransDate, @JobName, @OrigHost, @OrigUser, @OrigMQMUser, 0, GETDATE())
	END ELSE
	BEGIN
		UPDATE TrnFTEJob SET [Status] = 0 WHERE [JobId] = @JobId
	END
IF @@ERROR <> 0
BEGIN
    ROLLBACK
    RAISERROR('Error Updating Job File',16,1)
    RETURN
END
--- Update the Transaction File
	INSERT INTO TrnFTETransaction ([TransactionId], [JobId], [TransDate],[SourceAgent], [SourceQM], [SourceAgentInfo], [DestAgent], [DestQM], [DestAgentInfo],[ProgressInfo], [MQACompId], [MQAInfo], [Supplemental], [SLAClass], [Status], [LastUpdate]) VALUES (@TransactionId, @JobId, @TransDate, @SourceAgent, @SourceQM, @SourceAgentInfo, @DestAgent, @DestQM, @DestAgentInfo, NULL, @MQACompId, @MQAInfo, @Supplemental, @SLAClass, 0, GETDATE())
IF @@ERROR <> 0
BEGIN
    ROLLBACK
    RAISERROR('Error Updating Job File',16,1)
    RETURN
END
--- Commit
COMMIT
END
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
IF EXISTS (SELECT * FROM #tmpErrors) ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT>0 BEGIN
PRINT 'The database update succeeded'
COMMIT TRANSACTION
END
ELSE PRINT 'The database update failed'
GO
DROP TABLE #tmpErrors
GO
SET NUMERIC_ROUNDABORT OFF
GO
SET XACT_ABORT, ANSI_PADDING, ANSI_WARNINGS, CONCAT_NULL_YIELDS_NULL, ARITHABORT, QUOTED_IDENTIFIER, ANSI_NULLS, NOCOUNT ON
GO
SET DATEFORMAT YMD
GO
-- Pointer used for text / image updates. This might not be needed, but is declared here just in case
DECLARE @pv binary(16)

BEGIN TRANSACTION

-- Add 1 row to [dbo].[MstList]
INSERT INTO [dbo].[MstList] ([ListType], [ListCode], [ListDesc], [AddInfo]) VALUES ('SLANotify', 'ERROR', 'Error Notify', N'<data><emailbody>Hi, This is to inform you that the SLA transaction has resulted in an error, Please consult the Attachment for more details</emailbody><emailsubject>Transaction SLA - Errors Encountered</emailsubject></data> ')

COMMIT TRANSACTION
GO
