SET NUMERIC_ROUNDABORT OFF
GO
SET ANSI_PADDING, ANSI_WARNINGS, CONCAT_NULL_YIELDS_NULL, ARITHABORT, QUOTED_IDENTIFIER, ANSI_NULLS ON
GO
IF EXISTS (SELECT * FROM tempdb..sysobjects WHERE id=OBJECT_ID('tempdb..#tmpErrors')) DROP TABLE #tmpErrors
GO
CREATE TABLE #tmpErrors (Error int)
GO
SET XACT_ABORT ON
GO
SET TRANSACTION ISOLATION LEVEL SERIALIZABLE
GO
BEGIN TRANSACTION
GO
PRINT N'Altering [dbo].[TrnFTETransaction]'
GO
ALTER TABLE [dbo].[TrnFTETransaction] ADD
[StatsInfo] [nvarchar] (max) COLLATE SQL_Latin1_General_CP1_CI_AS NULL
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Altering [dbo].[TrnFTEJob]'
GO
ALTER TABLE [dbo].[TrnFTEJob] ADD
[OrigInfo] [nvarchar] (500) COLLATE SQL_Latin1_General_CP1_CI_AS NULL
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Altering [dbo].[TrnFTEFile]'
GO
ALTER TABLE [dbo].[TrnFTEFile] ADD
[SourceType] [int] NULL CONSTRAINT [DF_TrnFTEFile_SourceType] DEFAULT ((0)),
[DestType] [int] NULL CONSTRAINT [DF_TrnFTEFile_DestType] DEFAULT ((0))
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Altering [dbo].[InsertFTEFile]'
GO
ALTER PROCEDURE [dbo].[InsertFTEFile] 
--- Routine to add an FTE Transaction File
	@TransactionId NVARCHAR(50),
	@FileId INT,
	@Mode NVARCHAR(50),
	@SourceFile NVARCHAR(512),
	@SourceInfo NVARCHAR(512),
	@SourceType INT,
	@DestFile NVARCHAR(512),
	@DestInfo NVARCHAR(512),
	@DestType INT,
	@Result NVARCHAR(50),
	@Supplemental NTEXT
AS
BEGIN
	SET NOCOUNT ON;
	INSERT INTO TrnFTEFile ([TransactionId], [FileId], [Mode], [SourceFile], [SourceInfo], [SourceType], [DestFile], [DestInfo], [DestType], [Result], [Supplemental]) VALUES (@TransactionId, @FileId, @Mode, @SourceFile, @SourceInfo, @SourceType, @DestFile, @DestInfo, @DestType, @Result, @Supplemental)
END

GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Altering [dbo].[UpdateFTETransaction]'
GO
ALTER PROCEDURE [dbo].[UpdateFTETransaction] 
--- Routine to add update an FTE Transaction 
	@TransactionId NVARCHAR(50),
	@DestAgentInfo NVARCHAR(512),
	@Supplemental NTEXT,
	@StatsInfo NVARCHAR(MAX)
AS
BEGIN
	SET NOCOUNT ON;
	UPDATE TrnFTETransaction SET [DestAgentInfo] = @DestAgentInfo, [Supplemental] = @Supplemental, [StatsInfo]= @StatsInfo, [LastUpdate] = GETDATE() WHERE [TransactionId] = @TransactionId
END


GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Altering [dbo].[InsertFTETransaction]'
GO
ALTER PROCEDURE [dbo].[InsertFTETransaction] 
--- Routine to add FTE Header Records
	@TransactionId NVARCHAR(50),
	@TransDate DATETIME,
	@SourceAgent NVARCHAR(50),
	@SourceQM NVARCHAR(50),
	@SourceAgentInfo NVARCHAR(512),
	@DestAgent NVARCHAR(50),
	@DestQM NVARCHAR(50),
	@DestAgentInfo NVARCHAR(512),
	@JobId NVARCHAR(50),
	@JobName NVARCHAR(200),
	@OrigHost NVARCHAR(150),
	@OrigUser NVARCHAR(50),
	@OrigInfo NVARCHAR(500),
	@OrigMQMUser NVARCHAR(50),
	@MQACompId INT,
	@SLAClass NVARCHAR(50),
	@MQAInfo NTEXT,
	@Supplemental NTEXT
AS
BEGIN
	SET NOCOUNT ON;
	BEGIN TRANSACTION	
--- Update the Job File
    SELECT * FROM TrnFTEJob WHERE [JobId] = @JobId
    IF (@@ROWCOUNT <= 0)
    BEGIN
		INSERT INTO TrnFTEJob ([JobId], [JobDate], [Name], [OrigHost], [OrigUser], [OrigMQMUser],[Status], [LastUpdate],[OrigInfo]) VALUES (@JobId, @TransDate, @JobName, @OrigHost, @OrigUser, @OrigMQMUser, 0, GETDATE(),@OrigInfo)
	END ELSE
	BEGIN
		UPDATE TrnFTEJob SET [Status] = 0 WHERE [JobId] = @JobId
	END
IF @@ERROR <> 0
BEGIN
    ROLLBACK
    RAISERROR('Error Updating Job File',16,1)
    RETURN
END
--- Update the Transaction File
	INSERT INTO TrnFTETransaction ([TransactionId], [JobId], [TransDate],[SourceAgent], [SourceQM], [SourceAgentInfo], [DestAgent], [DestQM], [DestAgentInfo],[ProgressInfo], [MQACompId], [MQAInfo], [Supplemental], [SLAClass], [Status], [LastUpdate]) VALUES (@TransactionId, @JobId, @TransDate, @SourceAgent, @SourceQM, @SourceAgentInfo, @DestAgent, @DestQM, @DestAgentInfo, NULL, @MQACompId, @MQAInfo, @Supplemental, @SLAClass, 0, GETDATE())
IF @@ERROR <> 0
BEGIN
    ROLLBACK
    RAISERROR('Error Updating Job File',16,1)
    RETURN
END
--- Commit
COMMIT
END

GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating [dbo].[TmpForceComplete]'
GO
CREATE TABLE [dbo].[TmpForceComplete]
(
[TransactionId] [nvarchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
[UserId] [int] NOT NULL,
[Status] [int] NOT NULL,
[MQStatus] [int] NOT NULL,
[RequestDate] [datetime] NOT NULL,
[ErrorText] [nvarchar] (max) COLLATE SQL_Latin1_General_CP1_CI_AS NULL
)

GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
PRINT N'Creating primary key [PK_TmpForceComplete] on [dbo].[TmpForceComplete]'
GO
ALTER TABLE [dbo].[TmpForceComplete] ADD CONSTRAINT [PK_TmpForceComplete] PRIMARY KEY CLUSTERED ([TransactionId])
GO
IF @@ERROR<>0 AND @@TRANCOUNT>0 ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT=0 BEGIN INSERT INTO #tmpErrors (Error) SELECT 1 BEGIN TRANSACTION END
GO
IF EXISTS (SELECT * FROM #tmpErrors) ROLLBACK TRANSACTION
GO
IF @@TRANCOUNT>0 BEGIN
PRINT 'The database update succeeded'
COMMIT TRANSACTION
END
ELSE PRINT 'The database update failed'
GO
DROP TABLE #tmpErrors
GO
SET NUMERIC_ROUNDABORT OFF
GO
SET XACT_ABORT, ANSI_PADDING, ANSI_WARNINGS, CONCAT_NULL_YIELDS_NULL, ARITHABORT, QUOTED_IDENTIFIER, ANSI_NULLS, NOCOUNT ON
GO
SET DATEFORMAT YMD
GO
-- Pointer used for text / image updates. This might not be needed, but is declared here just in case
DECLARE @pv binary(16)

BEGIN TRANSACTION

-- Add 3 rows to [dbo].[MstList]
INSERT INTO [dbo].[MstList] ([ListType], [ListCode], [ListDesc], [AddInfo]) VALUES ('Feature', 'CANCELFTE', 'Can Request Cancellation of FTE Transactions', NULL)
INSERT INTO [dbo].[MstList] ([ListType], [ListCode], [ListDesc], [AddInfo]) VALUES ('Feature', 'COMPLETEFTE', 'Can Complete FTE Transaction', NULL)
SELECT * FROM [dbo].[MstList] WHERE [ListType] = 'FTEStatus' AND [ListCode] = '9'
IF (@@ROWCOUNT <= 0)
BEGIN
INSERT INTO [dbo].[MstList] ([ListType], [ListCode], [ListDesc], [AddInfo]) VALUES ('FTEStatus', '9', 'In-Progress - Errors', NULL)
END
UPDATE TrnFTEFile SET [SourceType] = 0 WHERE [SourceType] IS NULL
UPDATE TrnFTEFile SET [DestType] = 0 WHERE [DestType] IS NULL
COMMIT TRANSACTION
GO
